==> tailwindcss-logical-1.1.0.tgz: package/tests/output/borderRadius.js <==
module.exports = `
  .rounded-bs-none {
    border-start-start-radius: 0;
    border-start-end-radius: 0
  }

  .rounded-be-none {
    border-end-start-radius: 0;
    border-end-end-radius: 0
  }

  .rounded-is-none {
    border-start-start-radius: 0;
    border-end-start-radius: 0
  }

  .rounded-ie-none {
    border-start-end-radius: 0;
    border-end-end-radius: 0
  }

  .rounded-bs-sm {
    border-start-start-radius: 0.125rem;
    border-start-end-radius: 0.125rem
  }

  .rounded-be-sm {
    border-end-start-radius: 0.125rem;
    border-end-end-radius: 0.125rem
  }

  .rounded-is-sm {
    border-start-start-radius: 0.125rem;
    border-end-start-radius: 0.125rem
  }

  .rounded-ie-sm {
    border-start-end-radius: 0.125rem;
    border-end-end-radius: 0.125rem
  }

  .rounded-bs {
    border-start-start-radius: 0.25rem;
    border-start-end-radius: 0.25rem
  }

  .rounded-be {
    border-end-start-radius: 0.25rem;
    border-end-end-radius: 0.25rem
  }

  .rounded-is {
    border-start-start-radius: 0.25rem;
    border-end-start-radius: 0.25rem
  }

  .rounded-ie {
    border-start-end-radius: 0.25rem;
    border-end-end-radius: 0.25rem
  }

  .rounded-bs-md {
    border-start-start-radius: 0.375rem;
    border-start-end-radius: 0.375rem
  }

  .rounded-be-md {
    border-end-start-radius: 0.375rem;
    border-end-end-radius: 0.375rem
  }

  .rounded-is-md {
    border-start-start-radius: 0.375rem;
    border-end-start-radius: 0.375rem
  }

  .rounded-ie-md {
    border-start-end-radius: 0.375rem;
    border-end-end-radius: 0.375rem
  }

  .rounded-bs-lg {
    border-start-start-radius: 0.5rem;
    border-start-end-radius: 0.5rem
  }

  .rounded-be-lg {
    border-end-start-radius: 0.5rem;
    border-end-end-radius: 0.5rem
  }

  .rounded-is-lg {
    border-start-start-radius: 0.5rem;
    border-end-start-radius: 0.5rem
  }

  .rounded-ie-lg {
    border-start-end-radius: 0.5rem;
    border-end-end-radius: 0.5rem
  }

  .rounded-bs-xl {
    border-start-start-radius: 0.75rem;
    border-start-end-radius: 0.75rem
  }

  .rounded-be-xl {
    border-end-start-radius: 0.75rem;
    border-end-end-radius: 0.75rem
  }

  .rounded-is-xl {
    border-start-start-radius: 0.75rem;
    border-end-start-radius: 0.75rem
  }

  .rounded-ie-xl {
    border-start-end-radius: 0.75rem;
    border-end-end-radius: 0.75rem
  }

  .rounded-bs-2xl {
    border-start-start-radius: 1rem;
    border-start-end-radius: 1rem
  }

  .rounded-be-2xl {
    border-end-start-radius: 1rem;
    border-end-end-radius: 1rem
  }

  .rounded-is-2xl {
    border-start-start-radius: 1rem;
    border-end-start-radius: 1rem
  }

  .rounded-ie-2xl {
    border-start-end-radius: 1rem;
    border-end-end-radius: 1rem
  }

  .rounded-bs-3xl {
    border-start-start-radius: 1.5rem;
    border-start-end-radius: 1.5rem
  }

  .rounded-be-3xl {
    border-end-start-radius: 1.5rem;
    border-end-end-radius: 1.5rem
  }

  .rounded-is-3xl {
    border-start-start-radius: 1.5rem;
    border-end-start-radius: 1.5rem
  }

  .rounded-ie-3xl {
    border-start-end-radius: 1.5rem;
    border-end-end-radius: 1.5rem
  }

  .rounded-bs-full {
    border-start-start-radius: 9999px;
    border-start-end-radius: 9999px
  }

  .rounded-be-full {
    border-end-start-radius: 9999px;
    border-end-end-radius: 9999px
  }

  .rounded-is-full {
    border-start-start-radius: 9999px;
    border-end-start-radius: 9999px
  }

  .rounded-ie-full {
    border-start-end-radius: 9999px;
    border-end-end-radius: 9999px
  }

  .rounded-ss-none {
    border-start-start-radius: 0
  }

  .rounded-se-none {
    border-start-end-radius: 0
  }

  .rounded-es-none {
    border-end-start-radius: 0
  }

  .rounded-ee-none {
    border-end-end-radius: 0
  }

  .rounded-ss-sm {
    border-start-start-radius: 0.125rem
  }

  .rounded-se-sm {
    border-start-end-radius: 0.125rem
  }

  .rounded-es-sm {
    border-end-start-radius: 0.125rem
  }

  .rounded-ee-sm {
    border-end-end-radius: 0.125rem
  }

  .rounded-ss {
    border-start-start-radius: 0.25rem
  }

  .rounded-se {
    border-start-end-radius: 0.25rem
  }

  .rounded-es {
    border-end-start-radius: 0.25rem
  }

  .rounded-ee {
    border-end-end-radius: 0.25rem
  }

  .rounded-ss-md {
    border-start-start-radius: 0.375rem
  }

  .rounded-se-md {
    border-start-end-radius: 0.375rem
  }

  .rounded-es-md {
    border-end-start-radius: 0.375rem
  }

  .rounded-ee-md {
    border-end-end-radius: 0.375rem
  }

  .rounded-ss-lg {
    border-start-start-radius: 0.5rem
  }

  .rounded-se-lg {
    border-start-end-radius: 0.5rem
  }

  .rounded-es-lg {
    border-end-start-radius: 0.5rem
  }

  .rounded-ee-lg {
    border-end-end-radius: 0.5rem
  }

  .rounded-ss-xl {
    border-start-start-radius: 0.75rem
  }

  .rounded-se-xl {
    border-start-end-radius: 0.75rem
  }

  .rounded-es-xl {
    border-end-start-radius: 0.75rem
  }

  .rounded-ee-xl {
    border-end-end-radius: 0.75rem
  }

  .rounded-ss-2xl {
    border-start-start-radius: 1rem
  }

  .rounded-se-2xl {
    border-start-end-radius: 1rem
  }

  .rounded-es-2xl {
    border-end-start-radius: 1rem
  }

  .rounded-ee-2xl {
    border-end-end-radius: 1rem
  }

  .rounded-ss-3xl {
    border-start-start-radius: 1.5rem
  }

  .rounded-se-3xl {
    border-start-end-radius: 1.5rem
  }

  .rounded-es-3xl {
    border-end-start-radius: 1.5rem
  }

  .rounded-ee-3xl {
    border-end-end-radius: 1.5rem
  }

  .rounded-ss-full {
    border-start-start-radius: 9999px
  }

  .rounded-se-full {
    border-start-end-radius: 9999px
  }

  .rounded-es-full {
    border-end-start-radius: 9999px
  }

  .rounded-ee-full {
    border-end-end-radius: 9999px
  }
`;

==> tailwindcss-logical-2.0.0.tgz: package/tests/output/borderRadius.js <==
module.exports = `
  .rounded-bs-none {
    border-start-start-radius: 0px;
    border-start-end-radius: 0px
  }

  .rounded-be-none {
    border-end-start-radius: 0px;
    border-end-end-radius: 0px
  }

  .rounded-is-none {
    border-start-start-radius: 0px;
    border-end-start-radius: 0px
  }

  .rounded-ie-none {
    border-start-end-radius: 0px;
    border-end-end-radius: 0px
  }

  .rounded-bs-sm {
    border-start-start-radius: 0.125rem;
    border-start-end-radius: 0.125rem
  }

  .rounded-be-sm {
    border-end-start-radius: 0.125rem;
    border-end-end-radius: 0.125rem
  }

  .rounded-is-sm {
    border-start-start-radius: 0.125rem;
    border-end-start-radius: 0.125rem
  }

  .rounded-ie-sm {
    border-start-end-radius: 0.125rem;
    border-end-end-radius: 0.125rem
  }

  .rounded-bs {
    border-start-start-radius: 0.25rem;
    border-start-end-radius: 0.25rem
  }

  .rounded-be {
    border-end-start-radius: 0.25rem;
    border-end-end-radius: 0.25rem
  }

  .rounded-is {
    border-start-start-radius: 0.25rem;
    border-end-start-radius: 0.25rem
  }

  .rounded-ie {
    border-start-end-radius: 0.25rem;
    border-end-end-radius: 0.25rem
  }

  .rounded-bs-md {
    border-start-start-radius: 0.375rem;
    border-start-end-radius: 0.375rem
  }

  .rounded-be-md {
    border-end-start-radius: 0.375rem;
    border-end-end-radius: 0.375rem
  }

  .rounded-is-md {
    border-start-start-radius: 0.375rem;
    border-end-start-radius: 0.375rem
  }

  .rounded-ie-md {
    border-start-end-radius: 0.375rem;
    border-end-end-radius: 0.375rem
  }

  .rounded-bs-lg {
    border-start-start-radius: 0.5rem;
    border-start-end-radius: 0.5rem
  }

  .rounded-be-lg {
    border-end-start-radius: 0.5rem;
    border-end-end-radius: 0.5rem
  }

  .rounded-is-lg {
    border-start-start-radius: 0.5rem;
    border-end-start-radius: 0.5rem
  }

  .rounded-ie-lg {
    border-start-end-radius: 0.5rem;
    border-end-end-radius: 0.5rem
  }

  .rounded-bs-xl {
    border-start-start-radius: 0.75rem;
    border-start-end-radius: 0.75rem
  }

  .rounded-be-xl {
    border-end-start-radius: 0.75rem;
    border-end-end-radius: 0.75rem
  }

  .rounded-is-xl {
    border-start-start-radius: 0.75rem;
    border-end-start-radius: 0.75rem
  }

  .rounded-ie-xl {
    border-start-end-radius: 0.75rem;
    border-end-end-radius: 0.75rem
  }

  .rounded-bs-2xl {
    border-start-start-radius: 1rem;
    border-start-end-radius: 1rem
  }

  .rounded-be-2xl {
    border-end-start-radius: 1rem;
    border-end-end-radius: 1rem
  }

  .rounded-is-2xl {
    border-start-start-radius: 1rem;
    border-end-start-radius: 1rem
  }

  .rounded-ie-2xl {
    border-start-end-radius: 1rem;
    border-end-end-radius: 1rem
  }

  .rounded-bs-3xl {
    border-start-start-radius: 1.5rem;
    border-start-end-radius: 1.5rem
  }

  .rounded-be-3xl {
    border-end-start-radius: 1.5rem;
    border-end-end-radius: 1.5rem
  }

  .rounded-is-3xl {
    border-start-start-radius: 1.5rem;
    border-end-start-radius: 1.5rem
  }

  .rounded-ie-3xl {
    border-start-end-radius: 1.5rem;
    border-end-end-radius: 1.5rem
  }

  .rounded-bs-full {
    border-start-start-radius: 9999px;
    border-start-end-radius: 9999px
  }

  .rounded-be-full {
    border-end-start-radius: 9999px;
    border-end-end-radius: 9999px
  }

  .rounded-is-full {
    border-start-start-radius: 9999px;
    border-end-start-radius: 9999px
  }

  .rounded-ie-full {
    border-start-end-radius: 9999px;
    border-end-end-radius: 9999px
  }

  .rounded-ss-none {
    border-start-start-radius: 0px
  }

  .rounded-se-none {
    border-start-end-radius: 0px
  }

  .rounded-es-none {
    border-end-start-radius: 0px
  }

  .rounded-ee-none {
    border-end-end-radius: 0px
  }

  .rounded-ss-sm {
    border-start-start-radius: 0.125rem
  }

  .rounded-se-sm {
    border-start-end-radius: 0.125rem
  }

  .rounded-es-sm {
    border-end-start-radius: 0.125rem
  }

  .rounded-ee-sm {
    border-end-end-radius: 0.125rem
  }

  .rounded-ss {
    border-start-start-radius: 0.25rem
  }

  .rounded-se {
    border-start-end-radius: 0.25rem
  }

  .rounded-es {
    border-end-start-radius: 0.25rem
  }

  .rounded-ee {
    border-end-end-radius: 0.25rem
  }

  .rounded-ss-md {
    border-start-start-radius: 0.375rem
  }

  .rounded-se-md {
    border-start-end-radius: 0.375rem
  }

  .rounded-es-md {
    border-end-start-radius: 0.375rem
  }

  .rounded-ee-md {
    border-end-end-radius: 0.375rem
  }

  .rounded-ss-lg {
    border-start-start-radius: 0.5rem
  }

  .rounded-se-lg {
    border-start-end-radius: 0.5rem
  }

  .rounded-es-lg {
    border-end-start-radius: 0.5rem
  }

  .rounded-ee-lg {
    border-end-end-radius: 0.5rem
  }

  .rounded-ss-xl {
    border-start-start-radius: 0.75rem
  }

  .rounded-se-xl {
    border-start-end-radius: 0.75rem
  }

  .rounded-es-xl {
    border-end-start-radius: 0.75rem
  }

  .rounded-ee-xl {
    border-end-end-radius: 0.75rem
  }

  .rounded-ss-2xl {
    border-start-start-radius: 1rem
  }

  .rounded-se-2xl {
    border-start-end-radius: 1rem
  }

  .rounded-es-2xl {
    border-end-start-radius: 1rem
  }

  .rounded-ee-2xl {
    border-end-end-radius: 1rem
  }

  .rounded-ss-3xl {
    border-start-start-radius: 1.5rem
  }

  .rounded-se-3xl {
    border-start-end-radius: 1.5rem
  }

  .rounded-es-3xl {
    border-end-start-radius: 1.5rem
  }

  .rounded-ee-3xl {
    border-end-end-radius: 1.5rem
  }

  .rounded-ss-full {
    border-start-start-radius: 9999px
  }

  .rounded-se-full {
    border-start-end-radius: 9999px
  }

  .rounded-es-full {
    border-end-start-radius: 9999px
  }

  .rounded-ee-full {
    border-end-end-radius: 9999px
  }
`;
